@@ -1,15 +1,11 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import abc
 import warnings
+from typing import List, Sequence
 
-import six
 import typepy
 
 from ._core import TableData
@@ -17,18 +13,17 @@ from ._logger import logger
 from .error import InvalidHeaderNameError, InvalidTableNameError
 
 
-@six.add_metaclass(abc.ABCMeta)
-class TableDataNormalizerInterface(object):
+class TableDataNormalizerInterface(metaclass=abc.ABCMeta):
     """
     Interface class to validate and normalize data of |TableData|.
     """
 
     @abc.abstractmethod
-    def validate(self):  # pragma: no cover
+    def validate(self) -> None:  # pragma: no cover
         pass
 
     @abc.abstractmethod
-    def normalize(self):  # pragma: no cover
+    def normalize(self) -> TableData:  # pragma: no cover
         pass
 
 
@@ -49,7 +44,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
 
         return self.normalize()
 
-    def normalize(self):
+    def normalize(self) -> TableData:
         """
         :return: Sanitized table data.
         :rtype: tabledata.TableData
@@ -68,14 +63,14 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
         )
 
     @abc.abstractmethod
-    def _preprocess_table_name(self):
+    def _preprocess_table_name(self) -> str:
         """
         Always called before table name validation.
         You must return preprocessed table name.
         """
 
     @abc.abstractmethod
-    def _validate_table_name(self, table_name):
+    def _validate_table_name(self, table_name: str) -> None:
         """
         Must raise :py:class:`~.InvalidTableNameError`
         when you consider the table name invalid.
@@ -87,7 +82,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
         """
 
     @abc.abstractmethod
-    def _normalize_table_name(self, table_name):
+    def _normalize_table_name(self, table_name: str) -> str:
         """
         Must return a valid table name.
         The table name must be a valid name with
@@ -102,14 +97,14 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
         """
 
     @abc.abstractmethod
-    def _preprocess_header(self, col_idx, header):
+    def _preprocess_header(self, col_idx: int, header: str) -> str:
         """
         Always called before a header validation.
         You must return preprocessed header.
         """
 
     @abc.abstractmethod
-    def _validate_header(self, header):
+    def _validate_header(self, header: str) -> None:
         """
         No operation.
 
@@ -124,7 +119,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
         """
 
     @abc.abstractmethod
-    def _normalize_header(self, header):
+    def _normalize_header(self, header: str) -> str:
         """
         Must return a valid header name.
         This method called when :py:meth:`~._validate_header` method raise
@@ -137,14 +132,14 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
         :rtype: str
         """
 
-    def _normalize_rows(self, normalize_headers):
+    def _normalize_rows(self, normalize_headers: Sequence[str]) -> List:
         return self._tabledata.rows
 
-    def _validate_headers(self):
+    def _validate_headers(self) -> None:
         for header in self._tabledata.headers:
             self._validate_header(header)
 
-    def __normalize_table_name(self):
+    def __normalize_table_name(self) -> str:
         preprocessed_table_name = self._preprocess_table_name()
 
         try:
@@ -156,7 +151,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
 
         return new_table_name
 
-    def _normalize_headers(self):
+    def _normalize_headers(self) -> List[str]:
         new_header_list = []
 
         for col_idx, header in enumerate(self._tabledata.headers):
@@ -175,26 +170,26 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
 
 
 class TableDataNormalizer(AbstractTableDataNormalizer):
-    def _preprocess_table_name(self):
+    def _preprocess_table_name(self) -> str:
         return self._tabledata.table_name
 
-    def _validate_table_name(self, table_name):
+    def _validate_table_name(self, table_name: str) -> None:
         try:
             typepy.String(table_name).validate()
         except TypeError as e:
             raise InvalidTableNameError(e)
 
-    def _normalize_table_name(self, table_name):
+    def _normalize_table_name(self, table_name: str) -> str:
         return typepy.String(table_name).force_convert()
 
-    def _preprocess_header(self, col_idx, header):
+    def _preprocess_header(self, col_idx: int, header: str) -> str:
         return header
 
-    def _validate_header(self, header):
+    def _validate_header(self, header: str) -> None:
         try:
             typepy.String(header).validate()
         except TypeError as e:
             raise InvalidHeaderNameError(e)
 
-    def _normalize_header(self, header):
+    def _normalize_header(self, header: str) -> str:
         return typepy.String(header).force_convert()
